==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ro-RO/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'Un utilizator a acceptat un articol',
    'acceptance_asset_declined' => 'Un utilizator a refuzat un articol',
    'a_user_canceled' => 'Un utilizator a anulat o solicitare de element pe site',
    'a_user_requested' => 'Un utilizator a solicitat un element de pe site',
    'accessory_name' => 'Nume accesoriu:',
    'additional_notes' => 'Note Aditionale:',
    'admin_has_created' => 'Un administrator a creat un cont pentru dvs. pe: site-ul Web.',
    'asset' => 'activ:',
    'asset_name' => 'Numele activului:',
    'asset_requested' => 'Activul solicitat',
    'asset_tag' => 'Eticheta activ',
    'assigned_to' => 'Atribuit',
    'best_regards' => 'Toate cele bune,',
    'canceled' => 'Anulat:',
    'checkin_date' => 'Checkin Data:',
    'checkout_date' => 'Verifica data:',
    'click_to_confirm' => 'Dați clic pe următorul link pentru a vă confirma: contul web:',
    'click_on_the_link_accessory' => 'Dați clic pe linkul din partea de jos pentru a confirma că ați primit accesoriul.',
    'click_on_the_link_asset' => 'Faceți clic pe linkul din partea de jos pentru a confirma că ați primit activul.',
    'Confirm_Asset_Checkin' => 'Confirmare verificare active',
    'Confirm_Accessory_Checkin' => 'Confirmare verificare accesoriu',
    'Confirm_accessory_delivery' => 'Confirmare livrare accesoriu',
    'Confirm_license_delivery' => 'Confirmare livrare licenţă',
    'Confirm_asset_delivery' => 'Confirmare livrare active',
    'Confirm_consumable_delivery' => 'Confirmarea livrării consumabile',
    'current_QTY' => 'CTA curentă',
    'Days' => 'zi',
    'days' => 'zi',
    'expecting_checkin_date' => 'Data expirării așteptate:',
    'expires' => 'expiră',
    'Expiring_Assets_Report' => 'Raportul privind expirarea activelor.',
    'Expiring_Licenses_Report' => 'Certificatul de licență expirat.',
    'hello' => 'buna',
    'hi' => 'Bună',
    'i_have_read' => 'Am citit și sunt de acord cu termenii de utilizare și am primit acest articol.',
    'item' => 'Articol:',
    'Item_Request_Canceled' => 'Cererea de solicitare a fost anulată',
    'Item_Requested' => 'Elementul solicitat',
    'link_to_update_password' => 'Faceți clic pe următorul link pentru a vă actualiza parola web:',
    'login_first_admin' => 'Conectați-vă la noua dvs. instalare Snipe-IT utilizând următoarele acreditări:',
    'login' => 'Logare:',
    'Low_Inventory_Report' => 'Raport privind inventarul redus',
    'inventory_report' => 'Raport de inventar',
    'min_QTY' => 'Cantitate min',
    'name' => 'Nume',
    'new_item_checked' => 'Un element nou a fost verificat sub numele dvs., detaliile sunt de mai jos.',
    'password' => 'Parola:',
    'password_reset' => 'Resetare parola',

    'read_the_terms' => 'Citiți termenii de utilizare de mai jos.',
    'read_the_terms_and_click' => 'Citiți termenii de utilizare de mai jos și faceți clic pe link-ul din partea de jos pentru a confirma că ați citit și sunteți de acord cu termenii de utilizare și că ați primit materialul.',
    'requested' => 'Solicitat:',
    'reset_link' => 'Parola Resetare parolă',
    'reset_password' => 'Faceți clic aici pentru a vă reseta parola:',
    'serial' => 'Serial',
    'supplier' => 'Furnizor',
    'tag' => 'Etichetă',
    'test_email' => 'Testați e-mailul de la Snipe-IT',
    'test_mail_text' => 'Acesta este un test de la Snipe-IT Asset Management System. Dacă aveți acest lucru, poșta funcționează :)',
    'the_following_item' => 'Următorul articol a fost verificat în:',
    'low_inventory_alert' => 'Există :count articol care este sub nivelul minim de inventar sau care va fi în curând scăzut. Există :count articole care sunt sub nivelul minim de inventar sau care vor fi în curând scăzute.',
    'assets_warrantee_alert' => 'Există :count active cu o garanție care expiră în următoarele :prag zile.<unk> Există :count active cu garanții care expiră în următoarele :threshold zile.',
    'license_expiring_alert' => 'Există :count licență care expiră în următoarele :prag zile.<unk> Există :count licențe care expiră în următoarele :threshold zile.',
    'to_reset' => 'Pentru a vă reseta parola web, completați acest formular:',
    'type' => 'Tip',
    'upcoming-audits' => 'Există :count atuuri care vin pentru audit în :prag zile.• Există :count active care vin pentru audit în următoarele zile limită.',
    'user' => 'Utilizator',
    'username' => 'Utilizator',
    'welcome' => 'Bun venit: nume',
    'welcome_to' => 'Bun venit pe: web!',
    'your_credentials' => 'Informațiile dvs. Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accesoriu verificat în',
    'Asset_Checkin_Notification' => 'Activul verificat în',
    'Asset_Checkout_Notification' => 'Activ predat',
    'License_Checkin_Notification' => 'Licență verificată în',
    'Expected_Checkin_Report' => 'Raportul așteptat de verificare a activelor',
    'Expected_Checkin_Notification' => 'Notă: :name checkin termenul limită se apropie',
    'Expected_Checkin_Date' => 'Un activ verificat pentru tine urmează să fie verificat în data de :date',
    'your_assets' => 'Vezi activele tale',
    'rights_reserved' => 'Toate drepturile rezervate.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/ro-RO/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Accesoriu verificat în',
    'Accessory_Checkout_Notification' => 'Accesoriu predat',
    'Asset_Checkin_Notification' => 'Activul verificat în',
    'Asset_Checkout_Notification' => 'Activ predat',
    'Confirm_Accessory_Checkin' => 'Confirmare verificare accesoriu',
    'Confirm_Asset_Checkin' => 'Confirmare verificare active',
    'Confirm_accessory_delivery' => 'Confirmare livrare accesoriu',
    'Confirm_asset_delivery' => 'Confirmare livrare active',
    'Confirm_consumable_delivery' => 'Confirmarea livrării consumabile',
    'Confirm_license_delivery' => 'Confirmare livrare licenţă',
    'Consumable_checkout_notification' => 'Consumul a fost verificat',
    'Days' => 'zi',
    'Expected_Checkin_Date' => 'Un activ verificat pentru tine urmează să fie verificat în data de :date',
    'Expected_Checkin_Notification' => 'Notă: :name checkin termenul limită se apropie',
    'Expected_Checkin_Report' => 'Raportul așteptat de verificare a activelor',
    'Expiring_Assets_Report' => 'Raportul privind expirarea activelor.',
    'Expiring_Licenses_Report' => 'Certificatul de licență expirat.',
    'Item_Request_Canceled' => 'Cererea de solicitare a fost anulată',
    'Item_Requested' => 'Elementul solicitat',
    'License_Checkin_Notification' => 'Licență verificată în',
    'License_Checkout_Notification' => 'Licența a fost verificată',
    'Low_Inventory_Report' => 'Raport privind inventarul redus',
    'a_user_canceled' => 'Un utilizator a anulat o solicitare de element pe site',
    'a_user_requested' => 'Un utilizator a solicitat un element de pe site',
    'acceptance_asset_accepted' => 'Un utilizator a acceptat un articol',
    'acceptance_asset_declined' => 'Un utilizator a refuzat un articol',
    'accessory_name' => 'Nume accesoriu:',
    'additional_notes' => 'Note Aditionale:',
    'admin_has_created' => 'Un administrator a creat un cont pentru dvs. pe: site-ul Web.',
    'asset' => 'activ:',
    'asset_name' => 'Numele activului:',
    'asset_requested' => 'Activul solicitat',
    'asset_tag' => 'Eticheta activ',
    'assets_warrantee_alert' => 'Există :count active cu o garanție care expiră în următoarele :prag zile.<unk> Există :count active cu garanții care expiră în următoarele :threshold zile.',
    'assigned_to' => 'Atribuit',
    'best_regards' => 'Toate cele bune,',
    'canceled' => 'Anulat:',
    'checkin_date' => 'Checkin Data:',
    'checkout_date' => 'Verifica data:',
    'checkedout_from' => 'Verificat de la',
    'checkedin_from'  => 'Verificat de la',
    'checked_into' => 'Verificat în',
    'click_on_the_link_accessory' => 'Dați clic pe linkul din partea de jos pentru a confirma că ați primit accesoriul.',
    'click_on_the_link_asset' => 'Faceți clic pe linkul din partea de jos pentru a confirma că ați primit activul.',
    'click_to_confirm' => 'Dați clic pe următorul link pentru a vă confirma: contul web:',
    'current_QTY' => 'CTA curentă',
    'days' => 'zi',
    'expecting_checkin_date' => 'Data expirării așteptate:',
    'expires' => 'expiră',
    'hello' => 'buna',
    'hi' => 'Bună',
    'i_have_read' => 'Am citit și sunt de acord cu termenii de utilizare și am primit acest articol.',
    'inventory_report' => 'Raport de inventar',
    'item' => 'Articol:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Există :count licență care expiră în următoarele :prag zile.<unk> Există :count licențe care expiră în următoarele :threshold zile.',
    'link_to_update_password' => 'Faceți clic pe următorul link pentru a vă actualiza parola web:',
    'login' => 'Logare:',
    'login_first_admin' => 'Conectați-vă la noua dvs. instalare Snipe-IT utilizând următoarele acreditări:',
    'low_inventory_alert' => 'Există :count articol care este sub nivelul minim de inventar sau care va fi în curând scăzut. Există :count articole care sunt sub nivelul minim de inventar sau care vor fi în curând scăzute.',
    'min_QTY' => 'Cantitate min',
    'name' => 'Nume',
    'new_item_checked' => 'Un element nou a fost verificat sub numele dvs., detaliile sunt de mai jos.',
    'notes' => 'notițe',
    'password' => 'Parola:',
    'password_reset' => 'Resetare parola',
    'read_the_terms' => 'Citiți termenii de utilizare de mai jos.',
    'read_the_terms_and_click' => 'Vă rugăm să citiţi termenii de utilizare de mai jos, și faceți clic pe link-ul din partea de jos pentru a confirma că ați citit și sunteți de acord cu termenii de utilizare și ați primit activul.',
    'requested' => 'Solicitat:',
    'reset_link' => 'Parola Resetare parolă',
    'reset_password' => 'Faceți clic aici pentru a vă reseta parola:',
    'rights_reserved' => 'Toate drepturile rezervate.',
    'serial' => 'Serial',
    'snipe_webhook_test' => 'Test de integrare Snipe-IT',
    'snipe_webhook_summary' => 'Rezumatul testului de integrare Snipe-IT',
    'supplier' => 'Furnizor',
    'tag' => 'Etichetă',
    'test_email' => 'Testați e-mailul de la Snipe-IT',
    'test_mail_text' => 'Acesta este un test de la Snipe-IT Asset Management System. Dacă aveți acest lucru, poșta funcționează :)',
    'the_following_item' => 'Următorul articol a fost verificat în:',
    'to_reset' => 'Pentru a vă reseta parola web, completați acest formular:',
    'type' => 'Tip',
    'upcoming-audits' => 'Există :count atuuri care vin pentru audit în :prag zile.• Există :count active care vin pentru audit în următoarele zile limită.',
    'user' => 'Utilizator',
    'username' => 'Utilizator',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Bun venit: nume',
    'welcome_to' => 'Bun venit pe: web!',
    'your_assets' => 'Vezi activele tale',
    'your_credentials' => 'Informațiile dvs. Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
